@@ -34,8 +34,7 @@ Thus, all of the following:
 ...are valid expressions,
 with the "not", "and", and "or" keywords having their usual precedence
 (`pep8 or not @quick and @check` is parsed as
-`pep8 or ((@not quick) and @check)`, but the mini-language does not
-support parentheses yet).
+`pep8 or ((@not quick) and @check)`).
 
 Check whether an object matches a parsed specification
 ------------------------------------------------------
@@ -96,6 +95,7 @@ Select the test environments that match the specification:
     # Or if we only care about the names...
     quick_names = [env.name for env in all_envs if e_check_quick.evaluate(env)]
 
+
 """
 
 from .defs import VERSION, Tagged, TaggedFrozen  # isort: skip
@@ -104,16 +104,16 @@ from .p_pyp import EMPTY_SET_SPECS, parse_spec, parse_stage_ids  # isort: skip
 
 
 __all__ = [
+    "EMPTY_SET_SPECS",
     "VERSION",
-    "Tagged",
-    "TaggedFrozen",
     "AndExpr",
     "BoolExpr",
     "KeywordExpr",
     "NotExpr",
     "OrExpr",
     "TagExpr",
-    "EMPTY_SET_SPECS",
+    "Tagged",
+    "TaggedFrozen",
     "parse_spec",
     "parse_stage_ids",
 ]
