@@ -5,7 +5,6 @@
 from __future__ import annotations
 
 import dataclasses
-from typing import List
 
 
 @dataclasses.dataclass(frozen=True)
@@ -15,10 +14,10 @@ class TaggedFrozen:
     name: str
     """The name of the object, e.g. the name of the Tox test environment."""
 
-    tags: List[str]
+    tags: list[str]
     """The tags specified for this object."""
 
-    def get_keyword_haystacks(self) -> List[str]:
+    def get_keyword_haystacks(self) -> list[str]:
         """Get the strings to look for keywords in.
 
         Default: the object's `name` attribute.
@@ -33,10 +32,10 @@ class Tagged:
     name: str
     """The name of the object, e.g. the name of the Tox test environment."""
 
-    tags: List[str]
+    tags: list[str]
     """The tags specified for this object."""
 
-    def get_keyword_haystacks(self) -> List[str]:
+    def get_keyword_haystacks(self) -> list[str]:
         """Get the strings to look for keywords in.
 
         Default: the object's `name` attribute.
@@ -44,4 +43,4 @@ class Tagged:
         return [self.name]
 
 
-VERSION = "0.1.8"
+VERSION = "0.1.9"
